bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 8. Aventiure
___________________________________________________ #### <Wie Sifrit nach den Nibelvngen fvr>
| ### annen gie do Sifrit zer porten vf den sant ### in siner tarnkappe da er ein schifel vant ### daran so stuont vil tovgen daz Sigmvndes kint ### er fuort ez balde dannen als ob ez were der wint
###### 452 | ### Den schifmeiseer niemen sach daz schifel sere vloz ### von Sifrides kreften die waren also groz ### si wanden daz ez fuorte ein svnderstarker wint ### nein ez fuorte Sifrit der schoenen Siglinde kint
###### 453 | ### Bi des tages cite vnd bi der einen naht ### kom er zeime lande mit michelr kraft ### hvndert langer raste vnd dannoch lihte baz ### daz hiez Niblvnge da er den grozen hort besaz
###### 454 | ### Der helt fuor alleine vf einen wert bereit ### daz schif geband vil balde der riter vil gemeit ### er gie zuo eime berge darufe ein burch stuont ### vnd suchte herberge so die wegemude tuont
###### 455 | ### Do kom er fur die porten verslozen im div stuont ### ia huoten si ir êrn so noch die lute tuont ### anz tor begvnde bozen der vnkvnde man ### daz was wol behuotet do vant er innerthalben stan
###### 456 | ### einen vngefuegen der der burch phlach ### bi dem zallen ziten sin gewefen lach ### der sprach der ist der bozet so vaste an daz tor ### do wandelte sine stimme der kuene Sifrit dauor
###### 457 | ### vnd sprach ich bin ein reke entsliuz vf daz tor ### ich erzvrne eteslichen noch hivte da uor ### der gerne sampfte lege vnd hete sin gemach ### daz muote den portenere do daz Sifrit gesprach
###### 458 | ### Nv hete der rise kuene sin gewafen an getan ### sinen helmen vf sin hovbet der vil searke man ### den schilt vil balde zvchte daz tor er vf swief ### wie rehte gremliken er do an Sifriden lief
###### 459 | ### Wi er getorste wechen so manigen kuenen man ### da wrden slege swinde von siner hant getan ### do begund im schirmen der herlike gast ### doch schuof der portenere daz im sin spenge zebrast
###### 460 | ### von einer isensteine des gie dem helde not ### ein teil begvnde fvrhten der helt den grimmen tot ### do der portenere so kriftechlichen sluoch ### darvmbe was im weg der herre Sifrit genuoch [19b]
###### 461 | ### Si striten also sere daz al div burch erchal ### do horte man daz diezen Niblungen sal ### er twanch den portenere daz er in sit gebant ### div mere wrden kvnde in al der Niblunge lant
###### 462 | ### So horte daz striten verre durch den perch ### Albrich der kuone ein wildez getwerch ### er wafende sich balde vnde lief da er da vant ### disen gast vil edel da er den risen vaste gebant
###### 463 | ### Albrich was kuone dar zuo starch genuoch ### helm vnde ringe er an <dem> libe truoch ### vnd eine geisel swere von golde an siner hant ### do lief er harte swinde da er Sifriden vant
###### 464 | ### Siben chnoepfe swere hiengen vor daran ### da mit er vmb die hende den schilt dem kuenen man ### sluoch so biterlichen daz im des vil zebrast ### des libes kom in sorge do der wetliche gast
###### 465 | ### Den scherm er von der hende gar zebrochen swanc ### do stiez er in die scheide ein wafen daz was lanc ### sinen kamerere wold er niht slahen tot ### er schonde siner lûte als im tvgent daz gebot
###### 466 | ### Mit starken sinen handen lief er Albrichen an ### vnd vie bi dem barte den altgrisen man ### er zogte in vngefuege daz er vil lûte erschre ### zvht des iungen heldes tet Albriche we
###### 467 | ### Lute rief der kuene nv lazet mich genesen ### vnd moht ich iemens eigevn an einen reken wesen ### dem swer ich des eide ich wær im vndertan ### ich diende iv ê ich stvrbe sprach der listige man
###### 468 | ### Er bant ovch Albrichen sam den risen ê ### die Sifrides krefte taten im vil we ### daz twerch begvnde vragen wie sit ir genant ### er sprach ich heize Sifrit ich wande ich were iv wolbechant
###### 469 | ### So wol mich dirre mere sprach Albrich daz getuuerch ### nu han ich wol erfvnden div herlichen werch ### daz ir von waren schvlden mvget landes herre wesen ### ich tuon swar ir gebietet daz ir lat mich genesen
###### 470 | ### Do sprach der herre Sifrit ir svlt vil balde gan ### vnd bringet mir der besten reken die wir han ### tvsent Niblunge daz mich die hie gesehen ### so wilich iv leides lazen hie niht geschehen
###### 471 | ### Dem risen vnd Albriche lost er do div bant ### do lief Albrich balde da er die rechen vant ### sorgende wachete er der Niblvnge man ### er sprach wol vof ir helde ir svlt ze Sifride gan
###### 472 | ### Si sprvngen von den beten vnd waren vil bereit ### tvsent riter snelle die wrden wol gekleit ### si giengen da si funden <Sifriden> stan ### da wart ein schoene gruozen ein teil mit werchern getan
###### 473 | ### Vil rechen was enzvndet man schancte im lutertranch ### daz si komen schiere er seit ins allen danch [20a] ### er sprach ir svlt hinnen mit samt mir uber fluot ### des vant er vil bereit di helde kuone vnde guot
###### 474 | ### Wol drisech tusent reken waren schiere komen ### vz den wurden tvsent der besten do genomen ### den brahte man ir helme vnd ander ir gewant ### wan er si fueren wolde in daz Bruonhilde lant
###### 475 | ### Er sprach ir guoten ritere daz wil ich iv sagen ### ir svlt vil kleider richiv da ze hove tragen ### wan vns da sehen muesen vil minnechlichiv wip ### darvmbe svlt ir zieren mit guoter wete den lip
###### 476 | ### An einem morgen frvo huoben si sich dan ### waz sneller geverten Sifrit do gewan ### si fuorten ros div guoten vnde herlich gewant ### si komen weigerlichen in daz Pruonhilde lant
###### 477 | ### Do stuonden in den cinnen div minnechlichen <kint> ### do sprach div kvnniginne weiz ieman wer di sint ### die ich dort sihe fliezen so verre vf dem se ### si fuerent segel wize die sint noch wizer danne sne
###### 478 | ### Do sprach der kvnich von Rine ez sint mine man ### die het ich an der verte hie nahen bi verlan ### die han ich besendet die sint nv frowe chomen ### der herlichen geste wart mit zvohten war genomen
###### 479 | ### Do sach man Sifriden vor in eime schife stan ### in herlicher wæte vnd ander manigen man ### do sprach div <kuniginne> her kvnich ir sult mir sagen ### sol ich die geste gruozen oder sol ichz verdagen
###### 480 | ### Er sprach ir svlt enkegne in fur daz palas gen ### ob ir si sehet gerne daz si daz wol versten ### do tet div kvneginne als ir der kvnich riet ### Sifriden mit dem gruoze von den anderen schiet
###### 481 | ### Man schuof in herberge vnd behielt in ir gewant ### do was so vil geste komen in daz lant ### daz si sich allenthalben drungen mit den scharn ### do wolden die vil kuenen heim zen Burgonden varn
###### 482 | ### Do sprach div kvniginne ich wold im wesen holt ### der geteilen kvnde min silber vnd min golt ### min vnd des kvniges gesten des ich so vil han ### do antwurte Danchwart des kuenenen Giselhers man
###### 483 | ### Vil edel kvnneginne lat mich der sluzel pflegen ### ich truowez so geteilen sprach der kuene degen ### swaz ich erwerbe schande die lat min eins sin ### daz er milte wære daz tet er grozlichen schin
###### 484 | ### Do sich Hagnen bruoder der slûzle vnderwant ### so manige riche gabe bot des heldes hant ### der ein march gerte dem wart so vil gegeben ### daz die armen alle mvosen frolichen leben
###### 485 | ### Wol bi hvndert phvnden gab er ane zal ### genuoge in richer wæte giengen vor dem sal ### die nie dauor getruogen so herliclhiv kleit ### daz gevriesch div kvnniginne ez was ir swere vnde leit [20b]
###### 486 | ### Do sprach div kuneginne her kvnich ich het des rat ### daz iwer kamerere mir wil miner wat ### lazen niht beliben er swendet gar min golt ### derz noch vnderstuende dem wold ich immer wesen holt
###### 487 | ### Do sprach von Trony Hagne frovwe iv si geseit ### ez hat der kvnnech von Rine golt vnde <kleit> ### also vil ce gebenne daz <wir> des haben rat ### daz wir von hinnen fueren iht der Prunhilde <wat>
###### 488 | ### Nein durch min liebe sprach div kvnnegin ### nv <lat> mir erfullen zweinzech leitschrin ### von golde vnd ovch siden daz geben sol min hant ### so wir uber komen heim in der Bvrgonden lant
###### 489 | ### Mit edelem gesteine ladete man ir div schrin ### ir selber kamerere da mite muoste sin ### si wold ez niht getrovwen den Giselhers man ### Gvnther vnd Hagne darvmbe lachen began
###### 490 | ### Do sprach div iunchfrowe wem laz ich miniv lant ### div sol ê hie bestifeen min vnd iwer hant ### do sprach der kvnich edele nv heizet her gan ### der iv dar zvo gevalle den sul wir voget wesen lan
###### 491 | ### Ein ir hohsten mage diu frowe bi ir sach ### er was ir mvoter brvoder zvo dem div maget sprach ### nv lat iv sin beuolhen min burge vnd ouch ir lant ### si rihten sich ze verte man sach si riten ovf <den> sant
###### 492 | ### Si fuorte mit ir dannen sehs vn ahcech wip ### darzuo hvndert meide vil schoene was der lip ### svmten sie niht langer si wolden gahen dan ### die si deheime liezen hei waz der weinen began
###### 493 | ### In tugentlichen zvhten div frowe rovmte ir lant ### si kvste ir næstiu friunt die si bi ir vant ### mit guotem urlovbe si chomen vf den se ### zvo ir vater lande kom diu frovwe nimmer me
###### 494 | ### Man horte uf ir verte maniger hande spil ### aller kurzewile der heten si vil ### ovch kom in zvo ir reise ein rehter wazzerwint ### si fuoren von dem lande daz beweinde maniger muoter kint
###### 495 | ### Doch wolt si den herren niht minnen vf der vart ### ez wart ir kvrzwile vnze <in> ir hûs gespart ### ze Wormez zuo der bvrge an eine hohzit ### dar si vil frovden rich komen mit ir helden sit

<<< Übersicht <<< vorige Seite nächste Seite >>>